---
title: <span class="badge builder"></span> WeekdayRange
---
# <span class="badge builder"></span> WeekdayRange

## Constructor

```python
WeekdayRange()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> alerting.WeekdayRange
```

### <span class="badge object-method"></span> begin

```python
def begin(begin: int) -> typing.Self
```

### <span class="badge object-method"></span> end

```python
def end(end: int) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [WeekdayRange](./object-WeekdayRange.md)
